@@ -1,6 +1,6 @@
 from typing import List, Optional
 
-from codenames.game import GameState
+from codenames.game.state import GameState
 from pydantic import BaseModel, root_validator
 
 from .base import ModelIdentifier, Solver
