@@ -1,6 +1,6 @@
 from typing import List
 
-from codenames.game import Guess, Hint
+from codenames.game.move import Guess, Hint
 from pydantic import BaseModel
 
 from .base import ModelIdentifier, Solver
